[gnome-power-manager] Increase the critical action timeout to 20 seconds



commit b417e43e14619bc2ac44142848c83dbf1ff738ab
Author: William Jon McCann <william jon mccann gmail com>
Date:   Tue Feb 23 17:37:02 2010 +0000

    Increase the critical action timeout to 20 seconds
    
    Signed-off-by: Richard Hughes <richard hughsie com>

 src/gpm-manager.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/src/gpm-manager.c b/src/gpm-manager.c
index ea10101..92d0551 100644
--- a/src/gpm-manager.c
+++ b/src/gpm-manager.c
@@ -1614,8 +1614,8 @@ gpm_manager_engine_charge_action_cb (GpmEngine *engine, DkpDevice *device, GpmMa
 
 		g_free (action);
 
-		/* wait 10 seconds for user-panic */
-		g_timeout_add_seconds (10, (GSourceFunc) manager_critical_action_do, manager);
+		/* wait 20 seconds for user-panic */
+		g_timeout_add_seconds (20, (GSourceFunc) manager_critical_action_do, manager);
 
 	} else if (type == DKP_DEVICE_TYPE_UPS) {
 		/* TRANSLATORS: UPS is really, really, low */



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]